==> sesame-rio-api-2.7.10-sources.jar: org/openrdf/rio/RDFWriterRegistry.java <==
/* 
 * Licensed to Aduna under one or more contributor license agreements.  
 * See the NOTICE.txt file distributed with this work for additional 
 * information regarding copyright ownership. 
 *
 * Aduna licenses this file to you under the terms of the Aduna BSD 
 * License (the "License"); you may not use this file except in compliance 
 * with the License. See the LICENSE.txt file distributed with this work 
 * for the full License.
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or 
 * implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package org.openrdf.rio;

import info.aduna.lang.service.FileFormatServiceRegistry;

/**
 * A registry that keeps track of the available {@link RDFWriterFactory}s.
 * 
 * @author Arjohn Kampman
 */
public class RDFWriterRegistry extends FileFormatServiceRegistry<RDFFormat, RDFWriterFactory> {

	private static RDFWriterRegistry defaultRegistry;

	/**
	 * Gets the default RDFWriterRegistry.
	 * 
	 * @return The default registry.
	 */
	public static synchronized RDFWriterRegistry getInstance() {
		if (defaultRegistry == null) {
			defaultRegistry = new RDFWriterRegistry();
		}

		return defaultRegistry;
	}

	public RDFWriterRegistry() {
		super(RDFWriterFactory.class);
	}

	@Override
	protected RDFFormat getKey(RDFWriterFactory factory) {
		return factory.getRDFFormat();
	}
}

==> sesame-rio-api-2.8.4-sources.jar: org/openrdf/rio/RDFWriterRegistry.java <==
/* 
 * Licensed to Aduna under one or more contributor license agreements.  
 * See the NOTICE.txt file distributed with this work for additional 
 * information regarding copyright ownership. 
 *
 * Aduna licenses this file to you under the terms of the Aduna BSD 
 * License (the "License"); you may not use this file except in compliance 
 * with the License. See the LICENSE.txt file distributed with this work 
 * for the full License.
 *
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or 
 * implied. See the License for the specific language governing permissions
 * and limitations under the License.
 */
package org.openrdf.rio;

import info.aduna.lang.service.FileFormatServiceRegistry;

/**
 * A registry that keeps track of the available {@link RDFWriterFactory}s.
 * 
 * @author Arjohn Kampman
 */
public class RDFWriterRegistry extends FileFormatServiceRegistry<RDFFormat, RDFWriterFactory> {

	private static RDFWriterRegistry defaultRegistry;

	/**
	 * Gets the default RDFWriterRegistry.
	 * 
	 * @return The default registry.
	 */
	public static synchronized RDFWriterRegistry getInstance() {
		if (defaultRegistry == null) {
			defaultRegistry = new RDFWriterRegistry();
		}

		return defaultRegistry;
	}

	public RDFWriterRegistry() {
		super(RDFWriterFactory.class);
	}

	@Override
	protected RDFFormat getKey(RDFWriterFactory factory) {
		RDFFormat key = factory.getRDFFormat();
		if (!RDFFormat.values().contains(key)) {
			RDFFormat.register(key);
		}
		return key;
	}
}
